SystemOrganization addCategory: #'Xpf-Server-Models'!
SystemOrganization addCategory: #'Xpf-Server-Tests'!
SystemOrganization addCategory: #'Xpf-Server-Rest'!
SystemOrganization addCategory: #'Xpf-Server-Rest-Tests'!

RestTest subclass: #XpfRestResourceTest
	instanceVariableNames: 'testProject testUser testTask'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Server-Rest-Tests'!

!XpfRestResourceTest methodsFor: 'running' stamp: 'cs 2/23/2009 15:49'!
setUp
	"Install a handler for http service. Add a test project to the database."

	| testStory |
	super setUp.
	RestHttpService service installHandler: XpfRestResourceHttpHandler on: '/'.
	testProject := (XpfProject new)
				title: 'Test Project';
				yourself.
	testUser := (XpfUser new)
				login: 'marcel.taeumel';
				yourself.
	testStory := (XpfUserStory new)
				title: 'Test UserStory';
				yourself.
	testTask := (XpfTask new)
				title: 'Test Task';
				explanation: 'This is a test task.';
				timeEstimated: 12;
				timeActual: 15;
				yourself.
	XpfProject addProject: testProject.
	XpfUser addUser: testUser.
	testProject addUserStory: testStory.
	testStory addTask: testTask! !

!XpfRestResourceTest methodsFor: 'running' stamp: 'cs 2/16/2009 01:29'!
tearDown
	super tearDown.
	(XpfProject all includes: testProject)
		ifTrue: [XpfProject deleteProject: testProject]! !

!XpfRestResourceTest methodsFor: 'tests' stamp: 'cs 2/19/2009 20:57'!
testDeleteOneProject
	"Try to delete a project via http DELETE request. This operation should be idempotent. Verify this by looking into the database directly."

	| projectCount response id |
	projectCount := XpfProject all size.
	id := testProject id.
	
	2 timesRepeat: [
		response := self delete: 'projects/', id asString.
	
		self 
			should: response responseCode = 200;
			should: XpfProject all size = (projectCount - 1);
			shouldnt: (XpfProject all anySatisfy: [:aProject| aProject id = id])].! !

!XpfRestResourceTest methodsFor: 'tests' stamp: 'cs 2/19/2009 20:57'!
testDeleteOneTask
	"Try to delete a task from testProject via http DELETE request. This operation should be idempotent. Verify this by looking into the database directly."

	| taskCount response id |
	taskCount := testProject tasks size.
	id := testTask id.
	
	2 timesRepeat: [
		response := self delete: ('projects/{1}/tasks/{2}' format: {testProject id. id}).
	
		self
			should: response responseCode = 200;
			should: testProject tasks size = (taskCount - 1);
			shouldnt: (testProject tasks anySatisfy: [:task| task id = id])].! !

!XpfRestResourceTest methodsFor: 'tests' stamp: 'mfp 2/20/2009 16:05'!
testGetAllProjects
	"Try to get a list with rest urls to all projects via http GET request. Verify this by looking into the database directly."

	| response responseContent restUrl |
	response := self get: 'projects'.
	responseContent := response content.
	
	self should: response responseCode = 200.
	
	response := Json readFrom: response content readStream.
	
	self should: XpfProject all size = response size.
	
	XpfProject all do: [:project |
		restUrl := '/projects/{1}' format:  {project id}.
		self should: (response includes: restUrl)].! !

!XpfRestResourceTest methodsFor: 'tests' stamp: 'SR 2/20/2009 13:46'!
testGetAllTasks
	"Try to get a list with rest urls to all tasks of testProject via http GET request. Verify this by looking into the database directly."

	| response responseContent restUrl |
	response := self get: ('projects/{1}/tasks' format: {testProject id}).
	responseContent := response content.
	
	self should: response responseCode = 200.
	
	response := Json readFrom: responseContent readStream.
	
	self should: testProject tasks size = response size.
	
	testProject tasks do: [:task |
		restUrl := '/projects/{1}/tasks/{2}' format:  {testProject id. task id}.
		self should: (response includes: restUrl)].! !

!XpfRestResourceTest methodsFor: 'tests' stamp: 'SR 2/20/2009 13:48'!
testGetOneProject
	"Try to get information about a project via http GET request. Verify this by looking into the database directly."

	| response responseContent restUrl |	
	response := self get: 'projects/', testProject id asString.
	responseContent := response content.
	
	self should: response responseCode = 200.
	
	response := Json readFrom: responseContent readStream.
	
	self 
		should: testProject title = (response at: 'title');
		should: testProject id = (response at: 'id');
	
		should: testProject userStories size = (response at: 'userStories') size;
		should: testProject tasks size = (response at: 'tasks') size;
		should: testProject developers size = (response at: 'developers') size.	
	
	testProject userStories do: [:story |
		restUrl := '/projects/{1}/userstories/{2}' format:  {testProject id. story id}.
		self should: ((response at: 'userStories') includes: restUrl)].

	testProject tasks do: [:task |
		restUrl := '/projects/{1}/tasks/{2}' format:  {testProject id. task id}.
		self should: ((response at: 'tasks') includes: restUrl)].
	
	testProject developers do: [:developer |
		restUrl := '/users/{1}' format:  {developer id}.
		self should: ((response at: 'developer') includes: restUrl)].! !

!XpfRestResourceTest methodsFor: 'tests' stamp: 'cs 2/21/2009 14:19'!
testGetOneTask
	"Try to get information about a task from testProject via http GET request. Verify this by looking into the database directly."

	| response responseContent restUrl |	
	response := self get: ('projects/{1}/tasks/{2}' format: {testProject id. testTask id}).
	responseContent := response content.
	
	self should: response responseCode = 200.
	
	response := Json readFrom: responseContent readStream.
	self
		should: testTask title = (response at: 'title');
		should: testTask id = (response at: 'id');
		should: testTask explanation = (response at: 'explanation');
		should: testTask timeEstimated = (response at: 'timeEstimated');
		should: testTask timeActual = (response at: 'timeActual');
		should: ('/projects/', testTask project id asString) = (response at: 'project');
	
		should: testTask userStories size = (response at: 'userStories') size;
		should: testTask developers size = (response at: 'developers') size.	
	
	testTask userStories do: [:story |
		restUrl := '/projects/{1}/userstories/{2}' format:  {testProject id. story id}.
		self should: ((response at: 'userStories') includes: restUrl)].
	
	testTask developers do: [:developer |
		restUrl := '/users/{1}' format:  {developer id}.
		self should: ((response at: 'developer') includes: restUrl)].! !

!XpfRestResourceTest methodsFor: 'tests' stamp: 'cs 2/23/2009 16:48'!
testPostAddProject
	"Try to create a new project via http POST request. Verify this by looking into the database directly."

	| response projectCount newProject |
	projectCount := XpfProject all size.
	response := self
		post: 'projects'
		content: (self jsonDataFrom: {'title' -> 'new test project'}).

	self should: XpfProject all size = (projectCount + 1).
	newProject := XpfProject all detect:
		[:aProject | aProject id = response content asURI pathComponents last asNumber].
	self 
		should: newProject title = 'new test project';
		should: response content = ('/projects/{1}' format: {newProject id})! !

!XpfRestResourceTest methodsFor: 'tests' stamp: 'cs 2/23/2009 17:15'!
testPostAddTask
	"Try to create a new task to testProject via http POST request. Verify this by looking into the database directly."
	
	| response tasksCount newTask |
	tasksCount := testProject tasks size.
	response := self
		post: ('projects/{1}/tasks' format: {testProject id})
		content: (self jsonDataFrom: {'title' -> 'new test task'. 'explanation' -> 'This is a test task.'. 'timeEstimated' -> 42}).
	
	self should: response responseCode = 200.
	
	response := response content.
	
	self should: testProject tasks size = (tasksCount + 1).
	
	newTask := testProject tasks detect:
		[:task | task id = response asURI pathComponents last asNumber].
	
	self
		should: response = ('/projects/{1}/tasks/{2}' format: {testProject id. newTask id});
		should: newTask title = 'new test task';
		should: newTask explanation = 'This is a test task.';
		should: newTask timeEstimated = 42;
		should: newTask project = testProject.! !

!XpfRestResourceTest methodsFor: 'tests' stamp: 'mfp 2/20/2009 14:48'!
testPostAttachDeveloperToTask
	"Try to attach testUser to testTask via http POST request. Verify this by looking into the database directly."
	
	| response developersCount |
	developersCount := testTask developers size.
	response := self
		post: ('projects/{1}/tasks/{2}/developers' format: {testProject id. testTask id})
		content: (self jsonDataFrom: {'args' -> {'/users/{1}' format: {testUser id}}}).
	
	self should: response responseCode = 200.
	
	response := Json readFrom: response content readStream.
	self
		should: testTask developers size = (developersCount + 1);
		should: (testTask developers includes: testUser);
		should: (response at: 'value') = ('/users/{1}' format: {testUser id}).! !

!XpfRestResourceTest methodsFor: 'tests' stamp: 'cs 2/19/2009 21:02'!
testPutOneProject
	"Try to update information for a project via http PUT request. This operation should be idempotent. Verify this by looking into the database directly."
	
	| projectCount response developersCount tasksCount userStoriesCount |
	projectCount := XpfProject all size.
	userStoriesCount := testProject userStories size.
	developersCount := testProject developers size.
	tasksCount := testProject tasks size.
	
	2 timesRepeat: [	
		response := self
			put: 'projects/', testProject id asString
			content: (self jsonDataFrom: {'title' -> 'New Title'}).
			
		self 
			should: response responseCode = 200;
			should: XpfProject all size = projectCount;
			should: testProject title = 'New Title';
		
			should: testProject userStories size = userStoriesCount;
			should: testProject developers size = developersCount;
			should: testProject tasks size = tasksCount].! !

!XpfRestResourceTest methodsFor: 'tests' stamp: 'cs 2/19/2009 21:04'!
testPutOneTask
	"Try to update information for a task of testProject via http PUT request. This operation should be idempotent. Verify this by looking into the database directly."
	
	| taskCount response developersCount userStoriesCount |
	taskCount := testProject tasks size.
	userStoriesCount := testProject userStories size.
	developersCount := testProject developers size.
	
	2 timesRepeat: [
		response := self
			put: ('projects/{1}/tasks/{2}' format: {testProject id. testTask id})
			content: (self jsonDataFrom: {'title' -> 'New Title'. 'explanation' -> 'New Explanation'. 'timeEstimated' -> 25. 'timeActual' -> 50}).
			
		self 
			should: response responseCode = 200;
			should: testProject tasks size = taskCount;
			should: testTask title = 'New Title';
			should: testTask explanation = 'New Explanation';
			should: testTask timeEstimated = 25;
			should: testTask timeActual = 50;
		
			should: testTask userStories size = userStoriesCount;
			should: testTask developers size = developersCount;
			should: testTask project = testProject].! !

Object subclass: #XpfEntity
	instanceVariableNames: 'id'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Server-Models'!

XpfEntity class
	instanceVariableNames: 'lastId'!

!XpfEntity commentStamp: 'mt 2/12/2009 12:20' prior: 0!
I am the abstract superclass of all entities in the system. These entities could be user stories, tasks, developers, themes, ...!

XpfEntity class
	instanceVariableNames: 'lastId'!

!XpfEntity class methodsFor: 'private' stamp: 'cs 2/21/2009 13:55'!
incrementId
	self pvtLastId: self pvtLastId + 1.
	^ self pvtLastId! !

!XpfEntity class methodsFor: 'initialization' stamp: 'cs 2/21/2009 13:55'!
initialize
	super initialize.
	self pvtLastId: 0.! !

!XpfEntity class methodsFor: 'accessing' stamp: 'cs 2/21/2009 13:54'!
pvtLastId
	^ lastId! !

!XpfEntity class methodsFor: 'accessing' stamp: 'cs 2/21/2009 13:54'!
pvtLastId: anObject
	lastId := anObject! !

!XpfEntity methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:41'!
id
	^ id! !

!XpfEntity methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:41'!
id: anObject
	id := anObject! !

!XpfEntity methodsFor: 'printing' stamp: 'cs 2/23/2009 17:12'!
jsonWriteOn: aStream
 	self restUri jsonWriteOn: aStream.! !

!XpfEntity methodsFor: 'printing' stamp: 'cs 2/23/2009 17:12'!
restUri
	^ (XpfRestResourceHttpHandler uriMapping at: self class) value: self! !

XpfEntity subclass: #XpfProject
	instanceVariableNames: 'title userStories tasks developers'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Server-Models'!

XpfProject class
	instanceVariableNames: 'projects'!

XpfProject class
	instanceVariableNames: 'projects'!

!XpfProject class methodsFor: 'registration' stamp: 'cs 2/23/2009 16:29'!
addNewProject: aDictionary

	^ self addProject: (XpfProject new title: (aDictionary at: 'title'))! !

!XpfProject class methodsFor: 'registration' stamp: 'topa 2/16/2009 10:34'!
addProject: aProject
	self projects add: aProject.
	aProject id: self incrementId.
	^ aProject! !

!XpfProject class methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:37'!
all
	^ self projects! !

!XpfProject class methodsFor: 'registration' stamp: 'topa 2/16/2009 10:37'!
deleteProject: aProject
	self projects remove: aProject.! !

!XpfProject class methodsFor: 'initialization' stamp: 'cs 2/21/2009 13:52'!
initialize
	super initialize.
	self projects: OrderedCollection new.! !

!XpfProject class methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:37'!
projects
	^ projects! !

!XpfProject class methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:38'!
projects: aCollection
	projects := aCollection.! !

!XpfProject methodsFor: 'attach-detach' stamp: 'cs 2/23/2009 15:51'!
addDeveloper: aUser 
	self developers add: aUser ifPresent: [^ aUser].
	XpfUser addUser: aUser.
	aUser addProject: self.
	^ aUser! !

!XpfProject methodsFor: 'attach-detach' stamp: 'cs 2/23/2009 17:14'!
addNewTask: aDictionary
	^ self addTask:
		(XpfTask new
			title: (aDictionary at: 'title');
			explanation: (aDictionary at: 'explanation');
			timeEstimated: (aDictionary at: 'timeEstimated'))! !

!XpfProject methodsFor: 'attach-detach' stamp: 'cs 2/23/2009 15:55'!
addNewUserStory: aDictionary
	^ self addUserStory:
		(XpfUserStory new
			title: (aDictionary at: 'title');
			priority: (aDictionary at: 'priority');
			timeEstimated: (aDictionary at: 'timeEstimated');
			timeActual: (aDictionary at: 'timeActual');
			explanation: (aDictionary at: 'explanation'))! !

!XpfProject methodsFor: 'attach-detach' stamp: 'cs 2/23/2009 15:49'!
addTask: aTask 
	aTask
		project: self;
		id: aTask class incrementId.
	^ self tasks add: aTask! !

!XpfProject methodsFor: 'attach-detach' stamp: 'cs 2/23/2009 15:49'!
addUserStory: aUserStory 
	aUserStory
		project: self;
		id: aUserStory class incrementId.
	^ self userStories add: aUserStory! !

!XpfProject methodsFor: 'attach-detach' stamp: 'topa 2/16/2009 10:38'!
attachDeveloper: aUser

	self developers add: aUser ifPresent: [^ aUser].
	XpfUser addUser: aUser.
	aUser attachProject: self.
	^ aUser! !

!XpfProject methodsFor: 'attach-detach' stamp: 'cs 2/21/2009 13:53'!
attachTask: aTask
	aTask
		project: self;
		id: aTask class incrementId.
	^ self tasks add: aTask! !

!XpfProject methodsFor: 'attach-detach' stamp: 'cs 2/21/2009 13:53'!
attachUserStory: aUserStory
	aUserStory
		project: self;
		id: aUserStory class incrementId.
	^ self userStories add: aUserStory
! !

!XpfProject methodsFor: 'deleting' stamp: 'cs 2/23/2009 14:20'!
delete
	self class deleteProject: self.! !

!XpfProject methodsFor: 'attach-detach' stamp: 'topa 2/16/2009 10:39'!
detachDeveloper: aUser
	
	self developers remove: aUser ifAbsent: [^ aUser].
	aUser detachProject: self.
	^ aUser! !

!XpfProject methodsFor: 'attach-detach' stamp: 'topa 2/16/2009 10:43'!
detachTask: aTask

	self tasks remove: aTask ifAbsent: [^ aTask].
	aTask project: nil.
	^ aTask! !

!XpfProject methodsFor: 'attach-detach' stamp: 'topa 2/16/2009 10:44'!
detachUserStory: aUserStory

	self userStories remove: aUserStory ifAbsent: [^ aUserStory].
	aUserStory project: nil.
	^ aUserStory! !

!XpfProject methodsFor: 'accessing' stamp: 'mt 2/13/2009 14:58'!
developers
	^ developers! !

!XpfProject methodsFor: 'accessing-private' stamp: 'mt 2/13/2009 14:58'!
developers: anObject
	developers := anObject! !

!XpfProject methodsFor: 'initialization' stamp: 'mig 2/20/2009 15:29'!
initialize
	super initialize.
	self
		userStories: OrderedCollection new;
		tasks: OrderedCollection new;
		developers: OrderedCollection new.
	! !

!XpfProject methodsFor: 'printing' stamp: 'cs 2/21/2009 14:08'!
jsonWriteOn: aStream
	('/projects/{1}' format: {self id})
		jsonWriteOn: aStream.! !

!XpfProject methodsFor: 'printing' stamp: 'SR 2/23/2009 12:17'!
printString
	^ self title ifNil: ['No Title']! !

!XpfProject methodsFor: 'attach-detach' stamp: 'cs 2/23/2009 15:51'!
removeDeveloper: aUser 
	self developers remove: aUser ifAbsent: [^ aUser].
	aUser removeProject: self.
	^ aUser! !

!XpfProject methodsFor: 'attach-detach' stamp: 'cs 2/23/2009 15:50'!
removeTask: aTask 
	self tasks remove: aTask ifAbsent: [^ aTask].
	aTask project: nil.
	^ aTask! !

!XpfProject methodsFor: 'attach-detach' stamp: 'cs 2/23/2009 15:50'!
removeUserStory: aUserStory 
	self userStories remove: aUserStory ifAbsent: [^ aUserStory].
	aUserStory project: nil.
	^ aUserStory! !

!XpfProject methodsFor: 'accessing' stamp: 'mt 2/13/2009 14:58'!
tasks
	^ tasks! !

!XpfProject methodsFor: 'accessing-private' stamp: 'mt 2/13/2009 14:58'!
tasks: anObject
	tasks := anObject! !

!XpfProject methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:09'!
title
	^ title! !

!XpfProject methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:09'!
title: anObject
	title := anObject! !

!XpfProject methodsFor: 'accessing' stamp: 'mt 2/13/2009 14:58'!
userStories
	^ userStories! !

!XpfProject methodsFor: 'accessing-private' stamp: 'mt 2/13/2009 14:58'!
userStories: anObject
	userStories := anObject! !

XpfEntity subclass: #XpfTask
	instanceVariableNames: 'title explanation userStories timeEstimated timeActual project developers'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Server-Models'!

!XpfTask commentStamp: 'mt 2/12/2009 12:22' prior: 0!
I am a task in tems of Extreme Programming.!

!XpfTask methodsFor: 'attach-detach' stamp: 'cs 2/23/2009 15:49'!
addDeveloper: aUser 
	self developers add: aUser ifPresent: [^ aUser].
	self project addDeveloper: aUser.
	aUser addTask: self.
	^ aUser! !

!XpfTask methodsFor: 'attach-detach' stamp: 'cs 2/23/2009 15:49'!
addUserStory: aUserStory 
	self userStories add: aUserStory ifPresent: [^ aUserStory].
	self project addUserStory: aUserStory.
	aUserStory addTask: self.
	^ aUserStory! !

!XpfTask methodsFor: 'attach-detach' stamp: 'SR 2/17/2009 15:15'!
attachDeveloper: aUser

	self developers add: aUser ifPresent: [^ aUser].
	self project attachDeveloper: aUser.
	aUser attachTask: self.
	^ aUser! !

!XpfTask methodsFor: 'attach-detach' stamp: 'topa 2/16/2009 10:33'!
attachUserStory: aUserStory

	self userStories add: aUserStory ifPresent: [^ aUserStory].	
	self project attachUserStory: aUserStory.
	aUserStory attachTask: self.
	^ aUserStory! !

!XpfTask methodsFor: 'deleting' stamp: 'cs 2/23/2009 15:50'!
delete
	"Deletes this task. Detaches all connections first."

	self userStories do: [:us | us removeTask: self].
	self developers do: [:devel | devel removeTask: self].
	self project removeTask: self! !

!XpfTask methodsFor: 'attach-detach' stamp: 'SR 2/17/2009 15:07'!
detachDeveloper: aUser
	
	self developers remove: aUser ifAbsent: [^ aUser].
	aUser detachTask: self.
	^ aUser! !

!XpfTask methodsFor: 'attach-detach' stamp: 'topa 2/16/2009 10:19'!
detachUserStory: aUserStory

	self userStories remove: aUserStory ifAbsent: [^ aUserStory].
	aUserStory detachTask: self.
	^ aUserStory! !

!XpfTask methodsFor: 'accessing' stamp: 'SR 2/17/2009 14:59'!
developers
	^ developers! !

!XpfTask methodsFor: 'accessing' stamp: 'SR 2/17/2009 14:59'!
developers: anObject
	developers := anObject! !

!XpfTask methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:10'!
explanation
	^ explanation! !

!XpfTask methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:10'!
explanation: anObject
	explanation := anObject! !

!XpfTask methodsFor: 'initialization' stamp: 'mig 2/20/2009 15:29'!
initialize
	super initialize.
	self 
		userStories: OrderedCollection new;
		developers: OrderedCollection new.! !

!XpfTask methodsFor: 'printing' stamp: 'cs 2/21/2009 14:08'!
jsonWriteOn: aStream
	('/projects/{1}/tasks/{2}' format: {self project id. self id})
		jsonWriteOn: aStream.! !

!XpfTask methodsFor: 'accessing' stamp: 'mt 2/14/2009 15:42'!
project
	^ project! !

!XpfTask methodsFor: 'accessing-private' stamp: 'mt 2/14/2009 15:42'!
project: anObject
	project := anObject! !

!XpfTask methodsFor: 'attach-detach' stamp: 'cs 2/23/2009 15:50'!
removeDeveloper: aUser 
	self developers remove: aUser ifAbsent: [^ aUser].
	aUser removeTask: self.
	^ aUser! !

!XpfTask methodsFor: 'attach-detach' stamp: 'cs 2/23/2009 15:50'!
removeUserStory: aUserStory 
	self userStories remove: aUserStory ifAbsent: [^ aUserStory].
	aUserStory removeTask: self.
	^ aUserStory! !

!XpfTask methodsFor: 'accessing' stamp: 'mt 2/14/2009 14:36'!
timeActual
	^ timeActual! !

!XpfTask methodsFor: 'accessing' stamp: 'mt 2/14/2009 14:36'!
timeActual: anObject
	timeActual := anObject! !

!XpfTask methodsFor: 'accessing' stamp: 'mt 2/14/2009 14:36'!
timeEstimated
	^ timeEstimated! !

!XpfTask methodsFor: 'accessing' stamp: 'mt 2/14/2009 14:36'!
timeEstimated: anObject
	timeEstimated := anObject! !

!XpfTask methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:10'!
title
	^ title! !

!XpfTask methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:10'!
title: anObject
	title := anObject! !

!XpfTask methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:10'!
userStories
	^ userStories! !

!XpfTask methodsFor: 'accessing-private' stamp: 'mt 2/13/2009 15:10'!
userStories: anObject
	userStories := anObject! !

XpfEntity subclass: #XpfUser
	instanceVariableNames: 'login firstName lastName email projects password tasks'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Server-Models'!

XpfUser class
	instanceVariableNames: 'users'!

!XpfUser commentStamp: 'mt 2/12/2009 12:24' prior: 0!
I am a system or application user. This could be an administrator, webmaster, developer or something like that.!

XpfUser class
	instanceVariableNames: 'users'!

!XpfUser class methodsFor: 'registration' stamp: 'cs 2/21/2009 13:54'!
addUser: aUser
	aUser id: self incrementId.
	^ self users add: aUser! !

!XpfUser class methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:20'!
all
	^ self users! !

!XpfUser class methodsFor: 'authentication' stamp: 'topa 2/16/2009 17:07'!
authenticate: aLogin by: aPassword
	
	^ self all 
		detect: [ :aUser| (aUser login = aLogin) and: [aUser authenticateBy: aPassword]]
		ifNone: [nil]! !

!XpfUser class methodsFor: 'registration' stamp: 'topa 2/16/2009 17:10'!
deleteUser: aUser
	^ self users remove: aUser ifAbsent: [^ aUser]
! !

!XpfUser class methodsFor: 'authentication' stamp: 'topa 2/16/2009 16:52'!
hash: aString
	^ SecureHashAlgorithm new hashMessage: aString! !

!XpfUser class methodsFor: 'initialization' stamp: 'mig 2/20/2009 15:35'!
initialize
	super initialize.
	self users: OrderedCollection new.! !

!XpfUser class methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:32'!
users 
	^ users! !

!XpfUser class methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:08'!
users: aCollection
	users := aCollection.! !

!XpfUser methodsFor: 'attach-detach' stamp: 'cs 2/23/2009 15:51'!
addProject: aProject 
	self projects add: aProject ifPresent: [^ aProject].
	XpfProject addProject: aProject.
	aProject addDeveloper: self.
	^ aProject! !

!XpfUser methodsFor: 'attach-detach' stamp: 'cs 2/23/2009 15:49'!
addTask: aTask 
	self tasks add: aTask ifPresent: [^ aTask].
	aTask addDeveloper: self.
	^ aTask! !

!XpfUser methodsFor: 'attach-detach' stamp: 'test 2/16/2009 10:30'!
attachProject: aProject

	self projects add:  aProject ifPresent: [^ aProject].
	XpfProject addProject: aProject.
	aProject attachDeveloper: self.
	^ aProject! !

!XpfUser methodsFor: 'attach-detach' stamp: 'SR 2/17/2009 15:13'!
attachTask: aTask

	self tasks add:  aTask ifPresent: [^ aTask].
	aTask attachDeveloper: self.
	^ aTask! !

!XpfUser methodsFor: 'authentication' stamp: 'topa 2/16/2009 16:53'!
authenticateBy: aString
	^ self pvtPassword = (self class hash: aString)! !

!XpfUser methodsFor: 'submorphs-add/remove' stamp: 'cs 2/23/2009 15:50'!
delete
	"Deletes this user. Detaches all connections first."

	self tasks do: [:task | task removeDeveloper: self].
	self projects do: [:project | project removeDeveloper: self]! !

!XpfUser methodsFor: 'attach-detach' stamp: 'test 2/16/2009 10:30'!
detachProject: aProject
	
	self projects remove: aProject ifAbsent: [^aProject].	
	aProject detachDeveloper: self.
	^ aProject! !

!XpfUser methodsFor: 'attach-detach' stamp: 'SR 2/17/2009 15:09'!
detachTask: aTask
	
	self tasks remove: aTask ifAbsent: [^aTask].	
	aTask detachDeveloper: self.
	^ aTask! !

!XpfUser methodsFor: 'accessing' stamp: 'test 2/16/2009 10:30'!
email
	^ email! !

!XpfUser methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:06'!
email: anObject
	email := anObject! !

!XpfUser methodsFor: 'accessing' stamp: 'test 2/16/2009 10:30'!
firstName
	^ firstName! !

!XpfUser methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:06'!
firstName: anObject
	firstName := anObject! !

!XpfUser methodsFor: 'attach-detach' stamp: 'mig 2/20/2009 15:30'!
initialize
	super initialize.
	self 
		projects: OrderedCollection new;
		tasks: OrderedCollection new.! !

!XpfUser methodsFor: 'printing' stamp: 'cs 2/21/2009 14:08'!
jsonWriteOn: aStream
	('/users/{1}' format: {self id})
		jsonWriteOn: aStream.! !

!XpfUser methodsFor: 'accessing' stamp: 'test 2/16/2009 10:30'!
lastName
	^ lastName! !

!XpfUser methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:06'!
lastName: anObject
	lastName := anObject! !

!XpfUser methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:31'!
login
	^ login! !

!XpfUser methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:06'!
login: anObject
	login := anObject! !

!XpfUser methodsFor: 'accessing' stamp: 'topa 2/16/2009 16:53'!
password: aString
	password := self class hash: aString! !

!XpfUser methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:31'!
projects
	^ projects! !

!XpfUser methodsFor: 'accessing-private' stamp: 'mt 2/14/2009 17:21'!
projects: anObject
	projects := anObject! !

!XpfUser methodsFor: 'accessing-private' stamp: 'topa 2/16/2009 16:46'!
pvtPassword
	^ password! !

!XpfUser methodsFor: 'attach-detach' stamp: 'cs 2/23/2009 15:51'!
removeProject: aProject 
	self projects remove: aProject ifAbsent: [^ aProject].
	aProject removeDeveloper: self.
	^ aProject! !

!XpfUser methodsFor: 'attach-detach' stamp: 'cs 2/23/2009 15:50'!
removeTask: aTask 
	self tasks remove: aTask ifAbsent: [^ aTask].
	aTask removeDeveloper: self.
	^ aTask! !

!XpfUser methodsFor: 'accessing' stamp: 'SR 2/17/2009 15:10'!
tasks
	^ tasks! !

!XpfUser methodsFor: 'accessing' stamp: 'SR 2/17/2009 15:10'!
tasks: anObject
	tasks := anObject! !

XpfEntity subclass: #XpfUserStory
	instanceVariableNames: 'title priority timeEstimated tasks timeActual explanation project'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Server-Models'!

!XpfUserStory commentStamp: 'topa 2/12/2009 14:06' prior: 0!
I am a user story in terms of Extreme Programming!

!XpfUserStory methodsFor: 'attach-detach' stamp: 'cs 2/23/2009 15:49'!
addTask: aTask 
	self tasks add: aTask ifPresent: [^ aTask].
	self project addTask: aTask.
	aTask addUserStory: self.
	^ aTask! !

!XpfUserStory methodsFor: 'attach-detach' stamp: 'test 2/16/2009 10:29'!
attachTask: aTask

	self tasks add: aTask ifPresent: [^ aTask].
	self project attachTask: aTask.
	aTask attachUserStory: self.
	^ aTask! !

!XpfUserStory methodsFor: 'deleting' stamp: 'cs 2/23/2009 15:50'!
delete
	"Deletes this user story from the system. Detaches all connections first."

	self tasks do: [:task | task removeUserStory: self].
	self project removeUserStory: self! !

!XpfUserStory methodsFor: 'attach-detach' stamp: 'topa 2/16/2009 10:20'!
detachTask: aTask

	self tasks remove: aTask ifAbsent: [^aTask].
	aTask detachUserStory: self.
	^ aTask! !

!XpfUserStory methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:20'!
explanation
	^ explanation! !

!XpfUserStory methodsFor: 'accessing' stamp: 'mt 2/14/2009 14:36'!
explanation: anObject
	explanation := anObject! !

!XpfUserStory methodsFor: 'initialization' stamp: 'mig 2/20/2009 15:30'!
initialize
	super initialize.
	self tasks: OrderedCollection new.! !

!XpfUserStory methodsFor: 'printing' stamp: 'cs 2/21/2009 14:08'!
jsonWriteOn: aStream
	('/projects/{1}/userstories/{2}' format: {self project id. self id})
		jsonWriteOn: aStream.! !

!XpfUserStory methodsFor: 'printing' stamp: 'mig 2/20/2009 15:46'!
printString
	^ self title ifNil: ['No Title']! !

!XpfUserStory methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:20'!
priority
	^ priority! !

!XpfUserStory methodsFor: 'accessing' stamp: 'mt 2/14/2009 14:36'!
priority: anObject
	priority := anObject! !

!XpfUserStory methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:20'!
project
	^ project! !

!XpfUserStory methodsFor: 'accessing-private' stamp: 'mt 2/14/2009 15:42'!
project: anObject
	project := anObject! !

!XpfUserStory methodsFor: 'attach-detach' stamp: 'cs 2/23/2009 15:50'!
removeTask: aTask 
	self tasks remove: aTask ifAbsent: [^ aTask].
	aTask removeUserStory: self.
	^ aTask! !

!XpfUserStory methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:20'!
tasks
	^ tasks! !

!XpfUserStory methodsFor: 'accessing-private' stamp: 'mt 2/14/2009 14:36'!
tasks: anObject
	tasks := anObject! !

!XpfUserStory methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:20'!
timeActual
	^ timeActual! !

!XpfUserStory methodsFor: 'accessing' stamp: 'mt 2/14/2009 14:36'!
timeActual: anObject
	timeActual := anObject! !

!XpfUserStory methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:20'!
timeEstimated
	^ timeEstimated! !

!XpfUserStory methodsFor: 'accessing' stamp: 'mt 2/14/2009 14:36'!
timeEstimated: anObject
	timeEstimated := anObject! !

!XpfUserStory methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:20'!
title
	^ title! !

!XpfUserStory methodsFor: 'accessing' stamp: 'mt 2/14/2009 14:36'!
title: anObject
	title := anObject! !

RestResourceHttpHandler subclass: #XpfRestResourceHttpHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Server-Rest'!

!XpfRestResourceHttpHandler class methodsFor: 'constants' stamp: 'cs 2/23/2009 17:00'!
resource
	^ Dictionary newFrom:
		{'projects' -> XpfProject.
		'users' -> XpfUser}! !

!XpfRestResourceHttpHandler class methodsFor: 'constants' stamp: 'cs 2/23/2009 17:01'!
rootResources
	^ Dictionary newFrom:
		{'projects' -> XpfProject.
		'users' -> XpfUser}! !

!XpfRestResourceHttpHandler class methodsFor: 'constants' stamp: 'cs 2/23/2009 17:13'!
uriMapping

	^ Dictionary newFrom:{
		XpfProject -> [:project| '/projects/{1}' format: {project id}].
		XpfUser -> [:user| '/users/{1}' format: {user id}].
		XpfTask -> [:task| '/projects/{1}/tasks/{2}' format: {task project id. task id}].
		XpfUserStory -> [:us | '/projects/{1}/userstories/{2}' format: {us project id. us id}]}! !

!XpfRestResourceHttpHandler methodsFor: 'constants' stamp: 'mt 2/23/2009 12:11'!
resources

	^ Dictionary newFrom:
		{'projects' -> XpfProject.
		'users' -> XpfUser}! !

!Collection methodsFor: '*xpf-server' stamp: 'cs 2/19/2009 14:07'!
add: anObject ifPresent: aBlock
	"Add an object if it is absent. Else run the block"

	(self includes: anObject) 
		ifFalse: [^ self add: anObject]
		ifTrue: [^ aBlock value]! !

TestCase subclass: #XpfTestCase
	instanceVariableNames: 'originalDatabase'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Server-Tests'!

XpfTestCase subclass: #XpfProjectTest
	instanceVariableNames: 'testProject testUser projects users'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Server-Tests'!

!XpfProjectTest methodsFor: 'running' stamp: 'topa 2/16/2009 17:27'!
setUp
	projects := XpfProject projects. XpfProject projects: Set new.
	users := XpfUser users. XpfUser users: Set new.
	testProject := XpfProject new title: 'testProject'.
	testUser := 	XpfUser new
			login: 'christopher.schuster';
			firstName: 'Christopher';
			lastName: 'Schuster';
			email: 'christopher.schuster@student.hpi.uni-potsdam.de'.! !

!XpfProjectTest methodsFor: 'running' stamp: 'topa 2/16/2009 17:27'!
tearDown
	XpfProject projects: projects.
	XpfUser users: users.
	testProject := nil.! !

!XpfProjectTest methodsFor: 'tests' stamp: 'mt 2/13/2009 16:06'!
testAttributes
	| user |
	user := XpfProject new.
	self
		checkAccessor: #title on: user with: 'xpforums'.! !

!XpfProjectTest methodsFor: 'tests' stamp: 'cs 2/23/2009 15:50'!
testHasDevelopers
	| developerCount userCount developer |
	developerCount := testProject developers size.
	userCount := XpfUser all size.
	developer := testProject addDeveloper: testUser.
	self
		should: XpfUser all size = (userCount + 1);
		should: testProject developers size = (developerCount + 1);
		should: (XpfUser all includes: developer);
		should: (testProject developers includes: developer).
	testProject removeDeveloper: developer.
	self
		should: XpfUser all size = (userCount + 1);
		should: testProject developers size = developerCount;
		should: (XpfUser all includes: developer);
		shouldnt: (testProject developers includes: developer)! !

!XpfProjectTest methodsFor: 'tests' stamp: 'mt 2/14/2009 15:29'!
testNewAndDelete
	| project oldCount |
	
	oldCount := XpfProject all size.
	
	project := XpfProject addProject:
		(XpfProject new
			title: 'xpforums';
			yourself).
		
	self 
		should: XpfProject all size = (oldCount + 1) description: 'Project count is not valid for database.';
		should: (XpfProject all anySatisfy: [ :each | each title = 'xpforums' ]).
	
	XpfProject deleteProject: project.
	
	self should: XpfProject all size = oldCount description: 'Project count is not valid for database after deletion.'.! !

XpfTestCase subclass: #XpfTaskTest
	instanceVariableNames: 'testProject'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Server-Tests'!

!XpfTaskTest methodsFor: 'running' stamp: 'mt 2/14/2009 15:18'!
setUp
	testProject := XpfProject new title: 'testProject'; yourself.! !

!XpfTaskTest methodsFor: 'running' stamp: 'mt 2/14/2009 15:18'!
tearDown
	testProject := nil.! !

!XpfTaskTest methodsFor: 'tests' stamp: 'mt 2/14/2009 14:37'!
testAttributes
	| t |
	t := XpfTask new.
	self
		checkAccessor: #title on: t with: 'SVN einrichten';
		checkAccessor: #explanation on: t with: 'SVN auf dem Server installieren und Benutzer einrichten.';
		checkAccessor: #timeEstimated on: t with: 10;
		checkAccessor: #timeActual on: t with: 12;
		checkAccessor: #userStories on: t with: (Set with: XpfUserStory new with: XpfUserStory new). ! !

!XpfTaskTest methodsFor: 'tests' stamp: 'cs 2/23/2009 15:50'!
testHasDevelopers
	| developer task developerCount |
	developerCount := testProject developers size.
	task := XpfTask new.
	developer := XpfUser new.
	self should: task developers size = 0.
	testProject addTask: task.
	task addDeveloper: developer.
	self
		should: task developers size = 1;
		should: testProject developers size = (developerCount + 1);
		should: (developer tasks includes: task).
	task removeDeveloper: developer.
	self
		should: task developers size = 0;
		should: testProject developers size = (developerCount + 1).
	task delete.
	developer delete! !

!XpfTaskTest methodsFor: 'tests' stamp: 'cs 2/23/2009 15:50'!
testHasUserStories
	| userStory task storyCount |
	storyCount := testProject userStories size.
	task := XpfTask new.
	userStory := XpfUserStory new.
	self should: task userStories size = 0.
	testProject addTask: task.
	task addUserStory: userStory.
	self
		should: task userStories size = 1;
		should: testProject userStories size = (storyCount + 1);
		should: (userStory tasks includes: task).
	task removeUserStory: userStory.
	self
		should: task userStories size = 0;
		should: testProject userStories size = (storyCount + 1).
	task delete.
	userStory delete! !

!XpfTaskTest methodsFor: 'tests' stamp: 'cs 2/23/2009 15:49'!
testNewAndDelete
	| task oldCount |
	oldCount := testProject tasks size.
	task := testProject addTask: ((XpfTask new)
						title: 'test task';
						explanation: 'this is a test task';
						yourself).
	self
		should: testProject tasks size = (oldCount + 1);
		should: (testProject tasks anySatisfy: [:each | each title = 'test task']).
	task delete.
	self should: testProject tasks size = oldCount! !

!XpfTestCase class methodsFor: 'testing' stamp: 'topa 2/13/2009 14:04'!
isAbstract
 	^self name = #XpfTestCase! !

!XpfTestCase methodsFor: 'test-helper' stamp: 'topa 2/12/2009 10:53'!
checkAccessor: aSelector on: aTargetObject with: anObject
	"test getter/setter aSelector of aTargetObject with anObject"
	
	aTargetObject perform: aSelector asMutator with: anObject.
	self
		should: (aTargetObject perform: aSelector) == anObject
		! !

!XpfTestCase methodsFor: 'test-helper' stamp: 'topa 2/12/2009 14:03'!
denyAccessor: aSelector on: aTargetObject with: anObject
	"test getter/setter aSelector of aTargetObject with anObject
	 that dont behave like plain accessors.
	"
	self
		shouldnt: (aTargetObject perform: aSelector) == anObject
		! !

XpfTestCase subclass: #XpfUserStoryTest
	instanceVariableNames: 'testProject'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Server-Tests'!

!XpfUserStoryTest methodsFor: 'running' stamp: 'mt 2/14/2009 14:48'!
setUp
	testProject := XpfProject new title: 'testProject'; yourself.! !

!XpfUserStoryTest methodsFor: 'running' stamp: 'mt 2/14/2009 14:48'!
tearDown
	testProject := nil.! !

!XpfUserStoryTest methodsFor: 'tests' stamp: 'mt 2/14/2009 14:44'!
testAttributes
	| us |
	us := XpfUserStory new.
	self
		checkAccessor: #title on: us with: 'US + Tasks verwalten';
		checkAccessor: #explanation on: us with: 'Dinge tun und Sachen machen';
		checkAccessor: #priority on: us with: 5;
		checkAccessor: #timeEstimated on: us  with: 10;
		checkAccessor: #timeActual on: us  with: 12;
		checkAccessor: #tasks on: us  with: (Set with: XpfTask new with: XpfTask new). 
		
! !

!XpfUserStoryTest methodsFor: 'tests' stamp: 'cs 2/23/2009 15:50'!
testHasTasks
	| userStory taskCount task |
	userStory := testProject addUserStory: XpfUserStory new.
	taskCount := testProject tasks size.
	self should: userStory tasks size = 0.
	task := userStory addTask: XpfTask new.
	self
		should: userStory tasks size = 1
			description: 'Task count for user story is invalid.';
		should: testProject tasks size = (taskCount + 1);
		should: (task userStories includes: userStory).
	userStory removeTask: task.
	self
		should: userStory tasks size = 0;
		should: testProject tasks size = (taskCount + 1).
	userStory delete.
	task delete! !

!XpfUserStoryTest methodsFor: 'tests' stamp: 'cs 2/23/2009 15:50'!
testNewAndDelete
	| userStory oldCount |
	oldCount := testProject userStories size.
	userStory := testProject addUserStory: ((XpfUserStory new)
						title: 'User Authentication';
						explanation: 'Users should register and login to the system.';
						priority: 3;
						timeEstimated: 10;
						yourself).
	self
		should: testProject userStories size = (oldCount + 1);
		should: (testProject userStories 
					anySatisfy: [:each | each title = 'User Authentication']).
	testProject removeUserStory: userStory.
	self should: testProject userStories size = oldCount! !

XpfTestCase subclass: #XpfUserTest
	instanceVariableNames: 'testUser users'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Server-Tests'!

!XpfUserTest class methodsFor: 'fixture-data' stamp: 'topa 2/16/2009 17:17'!
login
	^ 'test.user'! !

!XpfUserTest class methodsFor: 'fixture-data' stamp: 'topa 2/16/2009 17:17'!
password
	^ 'TEST'! !

!XpfUserTest methodsFor: 'running' stamp: 'topa 2/16/2009 17:23'!
setUp
	users := XpfUser users.
	XpfUser users: Set new.
	testUser := XpfUser new login: self class login; password: self class password.! !

!XpfUserTest methodsFor: 'running' stamp: 'topa 2/16/2009 17:23'!
tearDown
	XpfUser users: users.
	testUser := nil.! !

!XpfUserTest methodsFor: 'testing' stamp: 'mt 2/13/2009 15:12'!
testAttributes
	| user |
	user := XpfUser new.
	self
		checkAccessor: #login on: user with: 'marcel.taeumel';
		checkAccessor: #firstName on: user with: 'Marcel';
		checkAccessor: #lastName on: user with: 'Taeumel';
		checkAccessor: #email on: user with: 'marcel.taeumel@student.hpi.uni-potsdam.de'.! !

!XpfUserTest methodsFor: 'testing' stamp: 'cs 2/23/2009 15:51'!
testHasProjects
	| projectCount project globalProjectCount |
	projectCount := testUser projects size.
	globalProjectCount := XpfProject all size.
	project := testUser addProject: ((XpfProject new)
						title: 'xpforums';
						yourself).
	self
		should: XpfProject all size = (globalProjectCount + 1);
		should: testUser projects size = (projectCount + 1);
		should: (XpfProject all includes: project);
		should: (testUser projects includes: project).
	testUser removeProject: project.
	self
		should: XpfProject all size = (globalProjectCount + 1);
		should: testUser projects size = projectCount;
		should: (XpfProject all includes: project);
		shouldnt: (testUser projects includes: project)! !

!XpfUserTest methodsFor: 'testing' stamp: 'mt 2/14/2009 16:09'!
testNewAndDelete
	| user oldCount |
	
	self shouldnt: (XpfUser all anySatisfy: [ :each | each login = 'stefanc.richter' ]).
	
	oldCount := XpfUser all size.
	
	user := XpfUser addUser: (XpfUser new
			login: 'stefanc.richter';
			firstName: 'Stefan';
			lastName: 'Richter';
			email: 'stefanc.richter@student.hpi.uni-potsdam.de';
			yourself).
		
	self 
		should: XpfUser all size = (oldCount + 1);
		should: (XpfUser all anySatisfy: [ :each | each login = 'stefanc.richter' ]).
	
	XpfUser deleteUser: user.
	
	self should: XpfUser all size = oldCount.! !

!XpfUserTest methodsFor: 'testing' stamp: 'topa 2/16/2009 17:18'!
testPasswordHashing

	self 
		shouldnt: (testUser respondsTo: #password); "Write only"
		should: (testUser authenticateBy: self class password);
		shouldnt: (testUser authenticateBy: self class password , 'NOT').! !

!XpfUserTest methodsFor: 'testing' stamp: 'topa 2/16/2009 17:19'!
testUserAuthenticationFail

	XpfUser addUser: testUser.
	self
		should: (XpfUser authenticate: self class login by: self class password, 'NOT') isNil;
		should: (XpfUser authenticate: self class login, 'NOT' by: self class password) isNil;
		should: (XpfUser authenticate: self class login, 'NOT' by: self class password, 'NOT') isNil.
	
	XpfUser deleteUser: testUser.! !

!XpfUserTest methodsFor: 'testing' stamp: 'topa 2/16/2009 17:20'!
testUserAuthenticationSuccess

	XpfUser addUser: testUser.
	
	self should: testUser = (XpfUser authenticate: self class login  by: self class password).
	
	XpfUser deleteUser: testUser.! !
XpfEntity initialize!
XpfProject initialize!
XpfUser initialize!
